# frozen_string_literal: true

require "common_models/models/devices/gazebo/root_model"

module CommonModels
    module Devices
        module Gazebo
            describe RootModel do
            end
        end
    end
end
